@@ -171,6 +171,8 @@ void app_full_screen (Application *app) {
                     GTK_SIGNAL_FUNC (cbViewAreaFullscreenMapped), app);
             g_signal_connect (G_OBJECT (win), "unmap",
                     GTK_SIGNAL_FUNC (cbViewAreaFullscreenUnmapped), app);
+            g_signal_connect (G_OBJECT (win), "destroy",
+                    GTK_SIGNAL_FUNC (cb_fullscreen_destoyed), app);
             g_signal_connect (G_OBJECT (win), "key-press-event",
                     GTK_SIGNAL_FUNC (cb_keyPressed), (void *)app);
         }
@@ -457,7 +459,7 @@ static void create_menu (Application * app) {
     g_signal_connect (G_OBJECT (item_new), "activate",
         G_CALLBACK (callback_file_new), app);
     g_signal_connect( G_OBJECT( item_close ), "activate",
-        GTK_SIGNAL_FUNC (cb_mainview_deleted), app);
+        GTK_SIGNAL_FUNC (cb_mainview_close), app);
     g_signal_connect (G_OBJECT (item_open), "activate",
         GTK_SIGNAL_FUNC (callback_file_open), app);
     g_signal_connect (G_OBJECT (item_save), "activate",
@@ -620,8 +622,8 @@ int main (int argc, char* argv[]) {
     _app_setup_window (app->view_area, app);
     g_signal_connect (app->program, "notify::is-topmost",
         GTK_SIGNAL_FUNC (programTopMost), app);
-    g_signal_connect (G_OBJECT (main_window), "destroy",
-        GTK_SIGNAL_FUNC (cb_mainview_deleted), app);
+    g_signal_connect (G_OBJECT (main_window), "delete-event",
+        GTK_SIGNAL_FUNC (cb_mainview_delete), app);
     g_signal_connect (G_OBJECT (main_window), "expose-event",
         GTK_SIGNAL_FUNC (cb_window_expose), app);
     g_signal_connect (G_OBJECT (main_window), "notify::is-topmost",
@@ -638,7 +640,7 @@ int main (int argc, char* argv[]) {
         (GTK_SCROLLED_WINDOW (app->info_viewport), app->infopanel_view);
     g_object_set (G_OBJECT (app->infopanel_view),
             "cursor-visible", FALSE, "editable", FALSE,
-            "autocap", FALSE, "wrap-mode", GTK_WRAP_WORD, 0L);
+            "wrap-mode", GTK_WRAP_WORD, 0L);
     pango_cxt = gtk_widget_get_pango_context (app->infopanel_view);
     pfd = pango_font_description_from_string ("Sans 12");
     gtk_widget_modify_font (app->infopanel_view, pfd);
