@@ -104,10 +104,9 @@ KMPLAYER_NO_EXPORT void ASX::Entry::activate () {
         if (e->id == id_node_param) {
             Element * elm = convertNode <Element> (e);
             if (getAsxAttribute(elm,"name").lower() == String("clipsummary")) {
-                PlayListNotify * n = document ()->notify_listener;
-                if (n)
-                    n->setInfoMessage (URL::decode_string (
-                                getAsxAttribute (elm, "value")));
+                String inf = URL::decode_string (
+                                getAsxAttribute (elm, "value"));
+                document ()->message (MsgInfoString, &inf);
             }
         } else if (e->id == id_node_duration) {
             String s = convertNode <Element> (e)->getAttribute (
@@ -138,9 +137,7 @@ KDE_NO_EXPORT void *ASX::Entry::message (MessageType msg, void *content) {
 }
 
 KMPLAYER_NO_EXPORT void ASX::Entry::deactivate () {
-    PlayListNotify * n = document ()->notify_listener;
-    if (n)
-        n->setInfoMessage (String ());
+    document ()->message (MsgInfoString, NULL);
     if (duration_timer) {
         document()->cancelPosting (duration_timer);
         duration_timer = NULL;
