@@ -43,7 +43,7 @@ const short id_node_duration = 408;
 class KMPLAYER_NO_EXPORT Asx : public Mrl {
 public:
     KDE_NO_CDTOR_EXPORT Asx (NodePtr & d) : Mrl (d, id_node_asx) {}
-    NodePtr childFromTag (const String & tag);
+    Node *childFromTag (const String & tag);
     KDE_NO_EXPORT const char * nodeName () const { return "ASX"; }
     bool expose () const { return !pretty_name.isEmpty (); }
     PlayType playType ();
@@ -56,7 +56,7 @@ class Entry : public Mrl {
 public:
     KDE_NO_CDTOR_EXPORT Entry (NodePtr & d)
         : Mrl (d, id_node_entry), duration_timer (NULL), ref_child_count (0) {}
-    NodePtr childFromTag (const String & tag);
+    Node *childFromTag (const String & tag);
     void *message (MessageType msg, void *content=NULL);
     KDE_NO_EXPORT const char * nodeName () const { return "Entry"; }
     /**
@@ -77,7 +77,7 @@ public:
 class Ref : public Mrl {
 public:
     KDE_NO_CDTOR_EXPORT Ref (NodePtr & d) : Mrl (d, id_node_ref) {}
-    //NodePtr childFromTag (const String & tag);
+    //Node *childFromTag (const String & tag);
     void opened ();
     KDE_NO_EXPORT const char * nodeName () const { return "Ref"; }
     bool expose () const;
@@ -89,7 +89,7 @@ public:
 class EntryRef : public Mrl {
 public:
     KDE_NO_CDTOR_EXPORT EntryRef (NodePtr & d) : Mrl (d, id_node_entryref) {}
-    //NodePtr childFromTag (const String & tag);
+    //Node *childFromTag (const String & tag);
     void opened ();
     KDE_NO_EXPORT const char * nodeName () const { return "EntryRef"; }
 };
