@@ -32,8 +32,8 @@
 
 using namespace KMPlayer;
 
-KDE_NO_CDTOR_EXPORT FileDocument::FileDocument (short i, const String &s, KMPlayer::PlayListNotify * n)
- : KMPlayer::Document (s, n), load_tree_version ((unsigned int)-1) {
+KDE_NO_CDTOR_EXPORT FileDocument::FileDocument (short i, const String &s, KMPlayer::Control *src)
+ : KMPlayer::SourceDocument (src, s), load_tree_version ((unsigned int)-1) {
     id = i;
 }
 
@@ -144,13 +144,7 @@ KDE_NO_EXPORT void Playlist::defer () {
         KMPlayer::Document::defer ();
     else if (!resolved) {
         resolved = true;
-        String path = CONTROL(app)->m_config->readEntry
-            (GCONF_KEY_PLAYLIST_FILE, "/home/user/playlist.xml");
-        const char *tmp = (const char *)path;
-        struct stat st;
-        if (stat (tmp, &st))
-            tmp = "/usr/share/applications/kmplayer/playlist.xml";
-        readFromFile (tmp);
+        readFromFile (path);
     }
 }
 
@@ -161,8 +155,8 @@ KDE_NO_EXPORT void Playlist::activate () {
         defer ();
 }
 
-KDE_NO_CDTOR_EXPORT Playlist::Playlist (Application *a, KMPlayer::PlayListNotify *n, bool plmode)
-    : FileDocument (KMPlayer::id_node_playlist_document, "Playlist://", n),
+KDE_NO_CDTOR_EXPORT Playlist::Playlist (Application *a, KMPlayer::Control *s, bool plmode)
+    : FileDocument (KMPlayer::id_node_playlist_document, "Playlist://", s),
       app(a),
       playmode (plmode) {
     pretty_name = "Persistent Playlists";
@@ -197,7 +191,7 @@ KDE_NO_EXPORT void PlaylistItemBase::activate () {
     if (playmode) {
         Mrl::activate ();
     } else {
-        NodePtr pl = new Playlist (app, 0L, true);
+        NodePtr pl = new Playlist (app, CONTROL(app), true);
         String data;
         String pn;
         if (parentNode ()->id == KMPlayer::id_node_group_node &&
