@@ -22,6 +22,7 @@
 #define _KMPLAYER_LISTS_H_
 
 #include "kmplayerplaylist.h"
+#include "kmplayercontrol.h"
 
 typedef struct _Application Application;
 
@@ -34,9 +35,9 @@ static const short id_node_disk_node = 32;
 static const short id_node_html_object = 33;
 static const short id_node_html_embed = 34;
 
-class KMPLAYER_NO_EXPORT FileDocument : public KMPlayer::Document {
+class KMPLAYER_NO_EXPORT FileDocument : public KMPlayer::SourceDocument {
 public:
-    FileDocument (short id, const String &, KMPlayer::PlayListNotify * notify = 0L);
+    FileDocument (short id, const String &, KMPlayer::Control * notify = 0L);
     KMPlayer::Node *childFromTag (const String & tag);
     void readFromFile (const String & file);
     void writeToFile (const String & file);
@@ -86,13 +87,14 @@ public:
 
 class KMPLAYER_NO_EXPORT Playlist : public FileDocument {
 public:
-    Playlist (Application *a, KMPlayer::PlayListNotify *n, bool plmod = false);
+    Playlist (Application *a, KMPlayer::Control *n, bool plmod = false);
     void *message (KMPlayer::MessageType msg, void *content=NULL);
     void defer ();
     void activate ();
     KMPlayer::Node *childFromTag (const String & tag);
     KDE_NO_EXPORT const char * nodeName () const { return "playlist"; }
     Application * app;
+    String path;
     bool playmode;
 };
 
