@@ -98,6 +98,26 @@ static gboolean playCurrentSchedule (void * ctr) {
     return false;
 }
 
+SourceDocument::SourceDocument (Control *c, const String &url)
+    : Document (url, c), m_control (c) {}
+
+void *SourceDocument::message (MessageType msg, void *data) {
+    switch (msg) {
+
+    case MsgQueryRoleChildDisplay:
+        return VIEWAREA(m_control->m_app)->getSurface ((Mrl *) data);
+
+    case MsgInfoString:
+        app_set_info_content (m_control->m_app, 
+                data ? (const char *) *((String *) data) : "", false);
+        return NULL;
+
+    default:
+        break;
+    }
+    return Document::message (msg, data);
+}
+
 Control::Control (Application * a)
     : m_process (0L), m_doc_timer (0), progress_banner (NULL),
       playlist_data (0L), m_config (new Config), m_app (a),
@@ -141,10 +161,37 @@ void Control::init () {
                         "qgn_grid_tasknavigator_web", 26,
                         (GtkIconLookupFlags)0, 0L),
                     26, 26, GDK_INTERP_BILINEAR));
-    playlists = new KMPlayer::Playlist (m_app, 0L);
+    Playlist *pldoc = new Playlist (m_app, 0L);
+    playlists = pldoc;
+    String path = m_config->readEntry
+        (GCONF_KEY_PLAYLIST_FILE, "/home/user/playlist.xml");
+    const char *tmp = (const char *)path;
+    struct stat st;
+    if (stat (tmp, &st))
+        tmp = "/usr/share/applications/kmplayer/playlist.xml";
+    pldoc->path = tmp;
     m_app->playlists_tree_id = addTree (m_app, playlists,
             gtk_icon_theme_load_icon(icon_theme,
                 "qgn_list_gene_playlist", 26, (GtkIconLookupFlags)0, 0L));
+    GConfClient *client = (GConfClient *)(GConf &) *m_config;
+    GSList *plists = gconf_client_all_entries (client, GCONF_KEY_LISTS, NULL );
+    for (GSList *elm = plists; elm; elm = elm->next) {
+        GConfEntry *entry = (GConfEntry *)elm->data;
+        GConfValue *value = gconf_entry_get_value (entry);
+        const char *str = gconf_value_get_string (value);
+        debugLog() << entry->key << "=" << str << endl;
+        if (str && *str) {
+            Playlist *expl = new Playlist (m_app, 0L);
+            extra_playlists.append (expl);
+            expl->pretty_name = entry->key + strlen (GCONF_KEY_LISTS) + 1;
+            expl->path = str;
+            addTree (m_app, expl,
+                    gtk_icon_theme_load_icon(icon_theme,
+                      "qgn_list_gene_playlist", 26, (GtkIconLookupFlags)0, 0L));
+        }
+        gconf_entry_free (entry);
+    }
+    g_slist_free (plists);
     recents = new KMPlayer::Recents (m_app);
     m_app->recents_tree_id = addTree (m_app, recents,
             gtk_icon_theme_load_icon(icon_theme,
@@ -157,12 +204,14 @@ void Control::init () {
 void Control::deinit () {
     stop ();
     setProcess ((Process *) NULL);
+
     Recents *rec = static_cast <Recents *> (recents.ptr());
     if (rec->resolved &&
             rec->load_tree_version != rec->m_tree_version)
         rec->writeToFile (m_config->readEntry
                 (GCONF_KEY_RECENT_FILE, "/home/user/recent.xml"));
     rec->dispose ();
+
     Playlist *playlist = static_cast<Playlist *>(playlists.ptr());
     if (playlist->resolved &&
             playlist->load_tree_version != playlist->m_tree_version)
@@ -171,6 +220,10 @@ void Control::deinit () {
     if (m_app->save_folder)
         m_config->writeEntry (GCONF_KEY_SAVE_FOLDER, m_app->save_folder);
     playlist->dispose ();
+
+    for (NodePtr n = extra_playlists.first(); n; n = n->nextSibling ())
+        n->document()->dispose ();
+
     delete media_server;
     delete mplayer;
 #ifdef __ARMEL__
@@ -200,7 +253,7 @@ gboolean cb_scheduledUpdateTree (void * vp) {
     Control *ctr = static_cast <Control *> (vp);
     if (ctr->process ()) {
         if (!ctr->playlist_data->document)
-            ctr->playlist_data->document = new Document(String(), ctr);
+            ctr->playlist_data->document = new SourceDocument (ctr, String());
         updateTree (ctr->m_app, 0);
     }
     ctr->update_tree_timer = 0;
@@ -651,7 +704,16 @@ bool Control::setProcess (Mrl *mrl) {
     }
     String pname;
     bool changed = false;
-    if (!mrl->mimetype.isEmpty ())
+    if (id_node_playlist_item == mrl->id) {
+        String p = mrl->getAttribute ("player");
+        if (p == mplayer->name () || p == media_server->name ()
+#ifdef __ARMEL__
+                || p == npp->name ()
+#endif
+           )
+            pname = p;
+    }
+    if (pname.isEmpty () && !mrl->mimetype.isEmpty ())
         pname = processForMimetype (m_config, mrl->mimetype);
     if (pname.isEmpty ())
         pname = m_config->readEntry (GCONF_KEY_PLAYER, OssoMediaServer::myname);
@@ -812,14 +874,6 @@ void Control::updateViewAreaSizes () {
             video_rect.width (), video_rect.height ());
 }
 
-void Control::setInfoMessage (const String & msg) {
-    app_set_info_content (m_app, (const char *) msg, false);
-}
-
-Surface *Control::getSurface (Mrl *mrl) {
-    return VIEWAREA(m_app)->getSurface (mrl);
-}
-
 void Control::updatePlaylistView (bool force) {
     if (force) {
         if (update_tree_timer) {
@@ -976,10 +1030,6 @@ void Control::errorMsg (const String & msg) {
             NULL, (const char *) msg);
 }
 
-void Control::infoMsg (const String & msg) {
-    app_set_info_content (m_app, (const char *) msg, false);
-}
-
 void Control::setLoading (int perc) {
     if (perc >= 100) {
         if (progress_banner)
@@ -1033,7 +1083,12 @@ void Control::bitRates (int & prefered, int & maximal) {
 }
 
 PlayListData::PlayListData(short i, PlayListData * n)
-    : id (i), show_all (false), edit_mode (false), next (n) {}
+ : updated_document (NULL),
+   updated_document_version (0),
+   id (i),
+   show_all (false),
+   edit_mode (false),
+   next (n) {}
 
 Application *app_new () {
     Application *app = new Application;
@@ -1139,7 +1194,7 @@ void openFile (Application * app, const gchar * path) {
     PlayListData *pd = CONTROL(app)->playlist_data;
     if (pd->document)
         pd->document->document()->dispose ();
-    pd->document = new Document (String (path), CONTROL(app));
+    pd->document = new SourceDocument (CONTROL(app), String (path));
     CONTROL(app)->cur_url = path;
     g_timeout_add (0, playSchedule, static_cast <void *> (CONTROL(app)));
     CONTROL(app)->updatePlaylistView (true);
@@ -1174,7 +1229,7 @@ void newFile (Application * app) {
         pd->document->reset ();
         pd->document->document ()->dispose ();
     }
-    pd->document = new Document (String (), 0L);
+    pd->document = new SourceDocument (CONTROL(app), String ());
     CONTROL(app)->updatePlaylistView (true);
     CONTROL(app)->cur_url = String ();
 }
