@@ -429,10 +429,6 @@ String Node::nodeValue () const {
     return String ();
 }
 
-Surface *Node::getSurface (Mrl *) {
-    return NULL;
-}
-
 //-----------------------------------------------------------------------------
 
 RefNode::RefNode (NodePtr & d, NodePtr ref)
@@ -659,7 +655,8 @@ Mrl * Mrl::mrl () {
 }
 
 void *Mrl::message (MessageType msg, void *content) {
-    if (MsgMediaFinished == msg) {
+    switch (msg) {
+    case MsgMediaFinished:
         if (state == state_deferred &&
                 !isPlayable () && firstChild ()) {//if backend added child links
             state = state_activated;
@@ -667,6 +664,11 @@ void *Mrl::message (MessageType msg, void *content) {
         } else
             finish ();
         return NULL;
+    case MsgQueryRoleChildDisplay:
+        for (NodePtr p = parentNode (); p; p = p->parentNode ())
+            if (p->mrl ())
+                return p->message (msg, content);
+        return NULL;
     }
     return Node::message (msg, content);
 }
@@ -732,13 +734,6 @@ void Mrl::deactivate () {
 
 //----------------------%<-----------------------------------------------------
 
-Surface *Mrl::getSurface (Mrl *mrl) {
-    for (NodePtr p = parentNode (); p; p = p->parentNode ())
-        if (p->mrl ())
-            return p->getSurface (mrl);
-    return NULL;
-}
-
 void Mrl::parseParam (const TrieString & para, const String & val) {
     if (para == StringPool::attr_src && !src.startsWith ("#")) {
         String abs = absolutePath ();
@@ -1175,12 +1170,6 @@ void Document::proceed (const struct timeval &postponed_time) {
     deliver (MsgEventPostponed, &event);
 }
 
-Surface *Document::getSurface (Mrl *mrl) {
-    if (notify_listener)
-        return notify_listener->getSurface (mrl);
-    return NULL;
-}
-
 void *Document::message (MessageType msg, void *content) {
     if (MsgQueryReceivers == msg) {
         MessageType m = (MessageType) (long) content;
@@ -1234,6 +1223,8 @@ GenericURL::GenericURL (NodePtr & d, const String & s, const String & name)
     if (!src.isEmpty ())
         setAttribute (StringPool::attr_src, src);
     pretty_name = name;
+    if (!name.isEmpty ())
+        setAttribute (StringPool::attr_title, name);
 }
 
 KDE_NO_EXPORT void GenericURL::closed () {
