@@ -236,12 +236,16 @@ enum MessageType
     MsgStateFreeze,
     MsgStateRewind,
     MsgChildFinished,
+
     MsgStartQueryMessage,
     MsgQueryRoleTiming,
     MsgQueryRoleDisplay,
+    MsgQueryRoleChildDisplay,    // Mrl*
     MsgQueryRoleSizer,
     MsgQueryReceivers,
     MsgEndQueryMessage,
+
+    MsgInfoString                // String*
 };
 
 #define MsgUnhandled ((void *) 357L)
@@ -368,11 +372,6 @@ public:
      * Alternative to event handling is the Visitor pattern
      */
     virtual void accept (Visitor *);
-    /**
-     * Adds node to call 'message()' for all events that gets
-     * delivered to this node, ignored by default
-     */
-    virtual Surface *getSurface (Mrl *mrl);
     /**
      * Activates element, sets state to state_activated. Will call activate() on
      * firstChild or call deactivate().
@@ -541,10 +540,6 @@ public:
     virtual void undefer ();
     virtual void deactivate ();
     virtual void *message (MessageType msg, void *content=NULL);
-    /**
-     * By default support one event handler (eg. SMIL or RP child document)
-     */
-    virtual Surface *getSurface (Mrl *mrl);
 
     /**
      * If this Mrl is top node of external document, opener has the
@@ -581,14 +576,6 @@ public:
      * Element has activated or deactivated notification
      */
     virtual void stateElementChanged(Node *n, Node::State os, Node::State ns)=0;
-    /**
-     * Set element to which to send GUI events and return a surface for drawing
-     */
-    virtual Surface *getSurface (Mrl *mrl) = 0;
-    /**
-     * Request to show msg for informing the user
-     */
-    virtual void setInfoMessage (const String & msg) = 0;
     /**
      * Ask for connection bitrates settings
      */
@@ -738,10 +725,6 @@ public:
      * Document has list of postponed receivers, eg. for running (gif)movies
      */
     virtual void *message (MessageType msg, void *content=NULL);
-    /**
-     * Reimplement, so it will call PlayListNotify::getSurface()
-     */
-    virtual Surface *getSurface (Mrl *mrl);
 
     PlayListNotify *notify_listener;
     unsigned int m_tree_version;
