@@ -211,6 +211,7 @@ static gboolean findNode (PlayListData *pld, GtkTreeModel *model, Node *node, Gt
 void KMPlayer::updatePlayTree (Application *app) {
     app->in_tree_update = true;
     PlayListData *pld = CONTROL(app)->playlist_data;
+    GtkTreeView *treeview = GTK_TREE_VIEW (app->playlist_view);
 
     Node *node = pld->current.ptr ();
     if (!pld->show_all)
@@ -220,7 +221,7 @@ void KMPlayer::updatePlayTree (Application *app) {
         // undo selection
         return;
     }
-    GtkTreeModel *model = gtk_tree_view_get_model (GTK_TREE_VIEW (app->playlist_view));
+    GtkTreeModel *model = gtk_tree_view_get_model (treeview);
     GtkTreeIter iter;
     if (!gtk_tree_model_get_iter_first (model, &iter ))
         return;
@@ -228,7 +229,12 @@ void KMPlayer::updatePlayTree (Application *app) {
         //GdkPixbuf *icon = piter ? iconForNode (e.ptr (), 0) : pld->icon;
         GdkPixbuf *icon = iconForNode (node, 0);
         gtk_tree_store_set (GTK_TREE_STORE (model), &iter, COL_ICON, icon, -1);
-        gtk_tree_selection_select_iter (gtk_tree_view_get_selection (GTK_TREE_VIEW (app->playlist_view)), &iter);
+        //gtk_tree_selection_select_iter (gtk_tree_view_get_selection (GTK_TREE_VIEW (app->playlist_view)), &iter);
+        GtkTreePath *path = gtk_tree_model_get_path (model, &iter);
+        gtk_tree_view_expand_to_path (treeview, path);
+        gtk_tree_selection_select_path (gtk_tree_view_get_selection (treeview), path);
+        gtk_tree_view_scroll_to_cell (treeview, path, NULL, false, 0, 0);
+        gtk_tree_path_free (path);
     } else {
         errorLog() << "findNode return false" << endl;
     }
@@ -236,18 +242,18 @@ void KMPlayer::updatePlayTree (Application *app) {
 }
 
 void KMPlayer::updateTree (Application * app, short id) {
-    app->in_tree_update = true;
+    GtkTreeView *treeview = GTK_TREE_VIEW (app->playlist_view);
     GtkTreeIter valid_iter, *iter;
     GtkTreePath * fpath = 0L, * rpath;
     GtkTreeIter oldriter, riter;
     bool valid_tree = false;
-    PlayListData * playlist_data = CONTROL(app)->playlist_data;
-    GtkTreeModel *model = gtk_tree_view_get_model (GTK_TREE_VIEW (app->playlist_view));
-    g_object_ref (model);
-    gtk_tree_view_set_model (GTK_TREE_VIEW (app->playlist_view), NULL); //detach
-    //gtk_tree_store_clear (GTK_TREE_STORE (model));
+    PlayListData *pld = CONTROL(app)->playlist_data;
+    GtkTreeModel *model = gtk_tree_view_get_model (treeview);
+    GtkTreeSelection *sel = gtk_tree_view_get_selection (treeview);
+    Document *doc;
+
     for (valid_tree = gtk_tree_model_get_iter_first (model, &oldriter );
-            valid_tree && playlist_data;
+            valid_tree && pld;
             valid_tree = gtk_tree_model_iter_next (model, &oldriter )) {
         GValue value = { 0 , };
         gtk_tree_model_get_value (model, &oldriter, COL_ID, &value);
@@ -255,32 +261,66 @@ void KMPlayer::updateTree (Application * app, short id) {
         g_value_unset (&value);
         if (ival == id)
             break;
-        playlist_data = playlist_data->next;
+        pld = pld->next;
     }
-    if (!valid_tree || !playlist_data || !playlist_data->document)
+
+    if (!valid_tree || !pld || !pld->document) {
+        if (pld)
+            pld->updated_document = NULL;
         return;
-    valid_tree = gtk_tree_store_remove (GTK_TREE_STORE (model), &oldriter);
-    if (valid_tree)
-        gtk_tree_store_insert_before(GTK_TREE_STORE(model),&riter,0L,&oldriter);
-    else
-        gtk_tree_store_append (GTK_TREE_STORE(model), &riter, 0L);
-    rpath = gtk_tree_model_get_path (model, &riter);
-    populate (GTK_TREE_STORE (model), playlist_data,
-            playlist_data->document, &riter, 0L, &fpath);
-    gtk_tree_view_set_model (GTK_TREE_VIEW (app->playlist_view), model);//attach
-    g_object_unref (model);
-    if (!fpath)
-        fpath = rpath;
-    else
-        gtk_tree_path_free (rpath);
-    while (!gtk_tree_model_get_iter (model, &valid_iter, fpath) &&
-            gtk_tree_path_up (fpath));
-    //gchar * pstr = gtk_tree_path_to_string (fpath);
-    //g_print ("active path %s\n", pstr);
-    //g_free (pstr);
-    gtk_tree_view_expand_to_path(GTK_TREE_VIEW (app->playlist_view), fpath);
-    gtk_tree_selection_select_path (gtk_tree_view_get_selection (GTK_TREE_VIEW (app->playlist_view)), fpath);
-    gtk_tree_path_free (fpath);
+    }
+
+    app->in_tree_update = true;
+    doc = pld->document->document ();
+
+    if (!pld->id &&
+            pld->updated_document == doc &&
+            pld->updated_document_version == doc->m_tree_version &&
+            gtk_tree_model_get_iter_first (model, &riter )) {
+
+        if (pld->current &&
+                findNode (pld, model, pld->current.ptr (), &riter)) {
+            gtk_tree_selection_select_iter (sel, &riter);
+            fpath = gtk_tree_model_get_path (model, &riter);
+        }
+
+    } else {
+
+        g_object_ref (model);
+
+        gtk_tree_view_set_model (treeview, NULL); //detach
+
+        valid_tree = gtk_tree_store_remove (GTK_TREE_STORE (model), &oldriter);
+        if (valid_tree)
+            gtk_tree_store_insert_before(GTK_TREE_STORE(model),&riter,0L,&oldriter);
+        else
+            gtk_tree_store_append (GTK_TREE_STORE(model), &riter, 0L);
+        rpath = gtk_tree_model_get_path (model, &riter);
+        populate (GTK_TREE_STORE (model), pld,
+                pld->document, &riter, 0L, &fpath);
+        gtk_tree_view_set_model (treeview, model);//attach
+        if (!fpath)
+            fpath = rpath;
+        else
+            gtk_tree_path_free (rpath);
+
+        while (!gtk_tree_model_get_iter (model, &valid_iter, fpath) &&
+                gtk_tree_path_up (fpath));
+
+        g_object_unref (model);
+    }
+
+    if (fpath) {
+        gtk_tree_view_expand_to_path (treeview, fpath);
+        gtk_tree_selection_select_path (gtk_tree_view_get_selection (treeview), fpath);
+        gtk_tree_view_scroll_to_cell (treeview, fpath, NULL, false, 0, 0);
+        gtk_tree_path_free (fpath);
+    } else {
+        gtk_tree_selection_unselect_all (sel);
+    }
+
+    pld->updated_document = doc;
+    pld->updated_document_version = doc->m_tree_version;
     app->in_tree_update = false;
 }
 
@@ -416,6 +456,7 @@ gboolean cb_treeViewClicked (GtkWidget *view, GdkEventButton *evt, Application *
                 need_update = !gtk_tree_model_iter_has_child (model, &iter);
             }
             if ( need_update) {
+                pld->updated_document = NULL;
                 updateTree (app, pld->id);
                 gtk_tree_model_get_iter (model, &iter, path);
                 if (gtk_tree_model_iter_has_child (model, &iter)) {
@@ -434,16 +475,18 @@ gboolean cb_treeViewClicked (GtkWidget *view, GdkEventButton *evt, Application *
 void cb_selection_changed (GtkTreeSelection *selection, Application * app) {
     if (app->in_tree_update || !selection)
         return;
+    GtkTreeView *treeview = GTK_TREE_VIEW (app->playlist_view);
     GtkTreeIter iter;
     PlayListData * pld = 0L;
     NodePtr node;
     debugLog() << "tree selection changed" << endl;
     //g_print ("cb_selection_changed %d\n", app->playlist_data->show_all);
     if (gtk_tree_selection_get_selected (selection, 0L, &iter)) {
-        GtkTreeModel * model = gtk_tree_view_get_model (GTK_TREE_VIEW (app->playlist_view));
+        GtkTreeModel * model = gtk_tree_view_get_model (treeview);
         PlayListData * pld = getListData (app, model, &iter);
         restoreEditMode (app, pld);
         GtkTreePath* path = gtk_tree_model_get_path (model, &iter);
+        gtk_tree_view_scroll_to_cell (treeview, path, NULL, false, 0, 0);
         node = getNode (pld, path);
         gtk_tree_path_free (path);
         if (pld->id > 0 && node &&
@@ -796,6 +839,7 @@ void togglePlaylistShowAll (GtkCheckMenuItem *menuitem, Application * app) {
                 }
         }
         pld->show_all = selected;
+        pld->updated_document = NULL;
         //gtk_widget_set_sensitive (app->menu_item_playlist_edit, selected);
         if (pld->edit_mode && !selected) {
             gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (app->menu_item_playlist_edit), false);
@@ -830,6 +874,7 @@ void togglePlaylistEdit (GtkCheckMenuItem *menuitem, Application * app) {
                 }
         }
         pld->edit_mode = editable;
+        pld->updated_document = NULL;
         gtk_paned_set_position (app->vsplit_view, editable ? 0 : VSPLIT);
         if (!pld->show_all && editable)
             gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (app->menu_item_playlist_showall), true);
