@@ -196,6 +196,11 @@ KMPLAYER_NO_EXPORT unsigned int Process::viewer () const {
     return m_viewer;
 }
 
+KMPLAYER_NO_EXPORT void Process::infoMessage (const String &msg) {
+    if (m_mrl)
+        m_mrl->document ()->message (MsgInfoString, (void *) &msg);
+}
+
 //-----------------------------------------------------------------------------
 
 static void setupMPlayerFunc (gpointer data) {
@@ -572,7 +577,7 @@ KMPLAYER_NO_EXPORT void MPlayer::readEvent (GIOChannel * src) {
                                 char *e = strchr (t + 12, ';');
                                 if (e)
                                     *e = 0;
-                                processNotify ()->infoMsg (String (t + 12));
+                                infoMessage (String (t + 12));
                             }
                             handled = true;
                         }
@@ -692,8 +697,7 @@ static DBusHandlerResult filter_func (DBusConnection * connection,
                     const char * info;
                     dbus_message_iter_get_basic (&iter, &info);
                     printf ("iradio_update %s\n", info);
-                    process->processNotify ()->infoMsg (
-                            String (info) + process->stream_name);
+                    process->infoMessage (String (info) + process->stream_name);
                 } else
                     printf ("iradio_update %d\n", type);
             } else if (!strcmp (method, "details_received")) {
@@ -741,7 +745,7 @@ static DBusHandlerResult filter_func (DBusConnection * connection,
                                     s += value;
                                     s += "</i>";
                                     process->stream_name = s;
-                                    process->processNotify ()->infoMsg (s);
+                                    process->infoMessage (s);
                                 }
                             }
                         } else
